#include <iostream>
#include <cassert>
#include <set>
#include <queue>
#include <algorithm>
#include <string>
using namespace std;

#define REP(i, n) for(int i = 0; i < int(n); ++i)
#define DEB(x) cerr << #x << ":" << (x) << "\t at " << __LINE__ << endl
typedef long long hyper;

const int MAX_SIZE = 5000;


int minRadix(string const& num) {
	int res = 1;
	REP(i, num.size()) res = max(res, int(num[i] - '0') + 1);
	return res;
}

// We work with reversed notations, and zero not "0" but ""

hyper parse(string const& num, int radix) {
	assert(radix >= minRadix(num));
	hyper res = 0;
	hyper sig = 1;
	REP(i, num.size()) {
		//res += digits.find(num[i]) * sig;
		res += (num[i] - '0') * sig;
		sig *= radix;
	}
	return res;
}

string print(hyper num, int radix) {
	string res = "";
	while(num > 0) {
		res += (num % radix) + '0';
		num /= radix;
	}
	return res;
}

hyper R, L;
hyper LIM; //R**L

int compSize(hyper x) {

	set<hyper> passed;
	queue<hyper> q;
	q.push(x);
	while(!q.empty() && (int)passed.size() < MAX_SIZE) {
		hyper s = q.front();
		q.pop();
		if(s >= LIM || passed.count(s)) continue;
		passed.insert(s);
		for(int from = 2; from <= R; ++from) {
			string ss = print(s, from);
			if((int)ss.size() > L) continue;
			for(int to = minRadix(ss); to <= R; ++to) {
				hyper next = parse(ss, to);
				if(next <= LIM) {
					//cerr << s << " -> " << next << "\n";
					q.push(next);
				}
			}
		}
	}
	return passed.size();
}

hyper hpow(hyper base, hyper exp) {
	hyper res = 1;
	REP(i, exp) res *= base;
	return res;
}

void generate();
int main(int argc, char**argv) {

	string sx;
	while(cin >> R >> L >> sx) {
		assert(R >= 2 && R <= 10);
		assert(L >= 2 && L <= 10);
		//DEB(R);
		//DEB(L);
		LIM = hpow(R, L);
		//DEB(LIM);
		assert((int)sx.size() <= L);
		//DEB(sx);
		reverse(sx.begin(), sx.end());
		hyper x = parse(sx, R);
		assert(x >= 0 && x < LIM);
		//DEB(x);
		int cx = compSize(x);
		int c2 = compSize(2);
		cout << (cx < c2 ? "NO\n" : "YES\n");
 		if(false && cx > 10 && cx < c2) {
			cout << R << " " << L << " " << sx << "\n";
			DEB(cx);
			DEB(c2);
			cout << endl;
		}
	}
	return 0;
}

hyper rnd(hyper mod) {
	return (unsigned long long)(rand() * RAND_MAX * RAND_MAX + rand() * RAND_MAX + rand()) % mod;
}

void generate() {

	string samples[] = {
		"10 10 9999999999",
		"2 2 0",
		"2 2 1",
		"2 2 10",
		"10 10 1",
		"10 10 2",
		"10 10 9999999999",
		"10 10 8888888888",
		"10 10 7777777777",
		"10 10 7111111111",
		"7 6 255311",
		"5 7 103011",
		"9 10 5185533851",
		"10 10 480452802",
		"8 10 3404655142",
		"9 10 5032356064",
		"5 8 111002",
		"6 8 43241041",
		"7 10 4241004113",
		"5 7 420121",
		"5 7 4231",
		"7 9 424303333",
		"6 8 2033052",
		"7 9 61515213",
		"7 10 1245062601",
		"6 9 21021322",
		"5 6 22022",
		"7 8 3650531",
		"4 8 11001",
		"7 10 505120615",
		"6 10 52212503",
		"5 6 3103",
		"4 7 13033",
		"7 6 366102",
		"6 9 4221322",
		"7 8 4324325",
		"4 7 31233",
		"4 7 110011",
		"9 10 5167715822",
		"5 9 3001121",
		"4 5 11",
		"8 10 442626622",
		"6 10 241124122",
		"8 9 22061171",
		"4 9 10001012",
		"8 7 1212561",
	};
	
	REP(i, sizeof(samples) / sizeof(samples[0])) cout << samples[i] << "\n";
	
	srand(5);
	REP(i, 100) {
		hyper r = 2 + rnd(9); //2..10
		hyper l = 2 + rnd(9); //2..10
		hyper x = rnd(hpow(r, l));
		string sx = print(x, r);
		reverse(sx.begin(), sx.end());
		if(sx == "") sx = "0";
		cout << r << " " << l << " " << sx << "\n";
	}
}

